---
title: 포트원의 대표 고객사는 어떤 곳인가요?
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
seo:
  title: 포트원의 대표 고객사는 어떤 곳인가요?
  description: >-
    크림(Kream), 번개장터, 오늘의 집, 젠틀몬스터, 29CM, 무신사, 패스트캠퍼스, 노스페이스 등 포트원의 주요 고객사들을
    소개합니다.
  keywords:
    - 대표고객사
tags:
  - 공통
  - 대표고객사
pgCompanies:
  - 공통
searchTags:
  - reference
  - 포트원연동고객사
  - 포트원사용업체
  - 대표고객사
  - 포트원고객사
datetime: 2024-01-25T15:00:00.000Z
---

PortOne(포트원)과 함께 하시는 대표적인 기업을 소개합니다.

- 크림(Kream) <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" />
- 번개장터 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 오늘의 집 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 젠틀몬스터 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" /> <Tag text="해외결제" />
- 29CM (무신사) : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 패스트캠퍼스 : <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 노스페이스 : <Tag text="일반결제" /> <Tag text="네이버페이" />
- 펫프렌즈 : <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" />
- 뉴퍼마켓(구 AJ전시몰) : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 랜덤투유 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 원더월(wonderwall) : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="해외결제" />
- 월급쟁이부자들 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="토스페이" />
- 여신티켓 : <Tag text="일반결제" /> <Tag text="정기결제" />
- 혼다 코리아 : <Tag text="일반결제" />
- 웍스아웃 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="해외결제" />
- 화해 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 오픈갤러리 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" />
- 숨고 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" />
- 호갱노노 : <Tag text="정기결제" />
- 자비스 : <Tag text="일반결제" /> <Tag text="정기결제" />
- 오누이 : <Tag text="일반결제" /> <Tag text="정기결제" />
- 밀리의 서재 : <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" />
- 헤이딜러 : <Tag text="일반결제" />
- 마켓디자이너스(튜터링) : <Tag text="일반결제" /> <Tag text="정기결제" />
- 리디 주식회사(라프텔) : <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" /> <Tag text="해외결제" /> <Tag text="문화상품권" />
- 마플 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" /> <Tag text="해외결제" />
- 링글 : <Tag text="일반결제" /> <Tag text="정기결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" /> <Tag text="해외결제" />
- 놀이의 발견 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" /> <Tag text="토스페이" />
- 올웨이즈 : <Tag text="일반결제" /> <Tag text="카카오페이" /> <Tag text="네이버페이" /> <Tag text="페이코" />
- 퀸잇 : <Tag text="네이버페이" />
